@@ -23,8 +23,11 @@ class BitmexClient:
         return self.client.User.User_getWallet().result()[0][str(prop)]
 
     def get_position(self, symbol, prop):
-        return self.client.Position.Position_get(
+        try:
+            return self.client.Position.Position_get(
             filter=json.dumps({'symbol': symbol})).result()[0][0][str(prop)]
+        except IndexError:
+            return False
 
     def get_histories(self, symbols=['XBTUSD'], binSize='5m', count=15):
         histories = {}
@@ -79,7 +82,11 @@ class BitmexClient:
         return self.get_position(symbol, 'unrealisedPnl')
 
     def open_contracts(self, symbol):
-        return self.get_position(symbol, 'currentQty')
+        res = self.get_position(symbol, 'currentQty')
+        if res is not False:
+            return res
+        else:
+            return 0
 
     def current_price_position(self, symbol):
         return self.get_position(symbol, 'lastPrice')
@@ -177,12 +184,12 @@ class BitmexOrder:
 
     def calc_pos_size(self, symbol, sl_distance):
         acc_balance = self.client.acc_balance
-        ps = self.settings[symbol].position_size
+        ps = self.settings.symbols[symbol]['position_size']
         if symbol == 'XBTUSD':
             btc_usd = self.client.last_current_price(symbol)
             lot_step = 100
-            riskvalue = (acc_balance / 100000000) * \
-                btc_usd * (ps/100)  # riskvalue in usd
+            riskvalue = (float(acc_balance) / 100000000) * \
+                float(btc_usd) * (ps/100)  # riskvalue in usd
             pos_size = int(
                 round((math.floor(riskvalue / (sl_distance / btc_usd)) / lot_step)) * lot_step)
         elif symbol == 'ETHUSD':
