@@ -125,7 +125,7 @@ class Lotus:
                                     if sl_dist > 0.15 * sl_dist:
                                         time.sleep(2)
                                         contracts = self.order.calc_pos_size(
-                                            sl_dist)
+                                            symbol, sl_dist)
                                         print("Open market stop order short into open Signal. {} {} Contracts, Stoploss: {}".format(
                                             symbol, contracts, stoploss), flush=True)
                                         self.order.bracket_market_order(
@@ -136,7 +136,7 @@ class Lotus:
                             self.order.stoporder_cancel()  # cancel old order first
                             time.sleep(3)
                         contracts = self.order.calc_pos_size(
-                            abs(entry - stoploss))
+                            symbol, abs(entry - stoploss))
                         if self.order.props[symbol]['open']:
                             print("New signal is bracket stop long, but one bot order is open... closing open order in {}.".format(
                                 symbol), flush=True)
